# RSA
## Zigバージョン
0.14.0

## 関数
* 鍵ペアの作成: rsa.keyGen()
* サイン: rsa.sign(メッセージ, 送信者の秘密鍵, 送信者の公開鍵)
* 認証: rsa.verify(証明, メッセージ, 送信者の公開鍵)
* 暗号化: rsa.encrypt(メッセージ, 受付者の公開鍵)
* 復号化: rsa.decrypt(暗号されたメッセージ, 受付者の公開鍵, 受付者の秘密鍵)

## 使い方
```zig
// zig fmt: off
const std = @import("std");
const rsa = @import("rsa");

pub fn main() !void {
  std.debug.print("鍵を作成中・・・\n", .{});
  const aliceKeys = keyGen();
  std.debug.print("アリスちゃんの鍵：\n公開鍵： {any}\n秘密鍵： {any}\n", .{ aliceKeys.pubKey, aliceKeys.privKey });

  std.debug.print("鍵を作成中・・・\n", .{});
  const tanakaKeys = keyGen();
  std.debug.print("田中くんの鍵：\n公開鍵： {any}\n秘密鍵： {any}\n", .{ tanakaKeys.pubKey, tanakaKeys.privKey });

  const aliceSign = sign("暗号", aliceKeys.privKey, aliceKeys.pubKey);
  std.debug.print("アリスちゃんの「暗号」向けの証明： {any}\n", .{aliceSign});
  const tanakaVerify = verify(aliceSign, "暗号", aliceKeys.pubKey);
  std.debug.print("田中くんは証明を確認する： {any}\n", .{tanakaVerify});

  const aliceToTanakaEncrypted = encrypt("こんにちは", tanakaKeys.pubKey);
  std.debug.print("アリスちゃんは田中くんに「こんにちは」という暗号されたメッセージを送った： {any}\n", .{aliceToTanakaEncrypted});
  const aliceToTanakaDecrypted = decrypt(try aliceToTanakaEncrypted, tanakaKeys.pubKey, tanakaKeys.privKey);
  std.debug.print("田中くんはメッセージを復号された： {any}\n", .{aliceToTanakaDecrypted});
}
```
