// zig fmt: off
const std = @import("std");
const Sha = std.crypto.hash.sha2.Sha256;
const c = @import("constants.zig");

pub fn randomBytes() [c.hashOutBytes]u8 {
  var output: [c.hashOutBytes]u8 = undefined;
  std.posix.getrandom(output[0..]) catch unreachable;
  return output;
}

pub fn hashBytes(input: []const u8) [c.hashOutBytes]u8 {
  var sha2 = Sha.init(.{});
  sha2.update(input);
  return sha2.finalResult();
}

pub fn toInt(comptime T: type, bytes: []const u8) T {
  var res: T = 0;
  for (bytes) |byte| {
    res = (res << 8) | @as(T, byte);
  }

  return res;
}

pub fn fromInt(value: anytype, buf: []u8) void {
  var val = value;
  @memset(buf, 0);
  var i: usize = buf.len;
  while (i > 0 and val > 0) {
    i -= 1;
    buf[i] = @truncate(val);
    val >>= 8;
  }
}

test "bytes round-trip" {
  const value: u64 = 123456789;
  var buf: [c.rsaOutBytes]u8 = undefined;
  fromInt(value, buf[0..]);
  const back = toInt(c.rsaOutBits, buf[0..]);
  try std.testing.expectEqual(value, back);
}